@@ -1,10 +1,10 @@
 from clarifai_grpc.grpc.api import resources_pb2, service_pb2
-from clarifai_grpc.grpc.api.service_pb2_grpc import V2Stub
 from clarifai_grpc.grpc.api.status import status_code_pb2
 
+from clarifai_utils.client import V2Stub
+
 
 def installed_module_versions_generator(stub: V2Stub,
-                                        metadata: tuple,
                                         user_id: str,
                                         app_id: str,
                                         page_size: int = 64):
@@ -12,7 +12,7 @@ def installed_module_versions_generator(stub: V2Stub,
   Lists all the installed module versions in the given userAppID user_id, app_id app.
 
   Args:
-    stub: grpc client stub.
+    stub: client stub.
     user_id: the user to list from.
     app_id: the app in the user_id account to list from.
     page_size: the pagination size to use while iterating.
@@ -34,8 +34,7 @@ def installed_module_versions_generator(stub: V2Stub,
   while True:
     response = stub.ListInstalledModuleVersions(
         service_pb2.ListInstalledModuleVersionsRequest(
-            user_app_id=userDataObject, page=page, per_page=page_size),
-        metadata=metadata)
+            user_app_id=userDataObject, page=page, per_page=page_size),)
 
     if response.status.code not in imv_success_status:
       raise Exception("ListInstalledModuleVersions failed with response %r" % response)
